@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2008-2016 Statnet Commons
+#  Copyright 2008-2018 Statnet Commons
 #######################################################################
 library(ergm.count)
 set.seed(0)
@@ -21,11 +21,10 @@ y <- as.network(m, matrix.type="a", directed=TRUE, ignore.eval=FALSE, names.eval
 truth <- log(sum(m)/n/(n-1))
 diag(m) <- NA
 
-efit <- ergm(y ~ sum, response="w", reference=~Poisson, verbose=TRUE)
+efit <- ergm(y ~ sum, response="w", reference=~Poisson, verbose=TRUE, control=control.ergm(MCMLE.effectiveSize=128))
 
 summary(efit)
-
 true.llk <- sum(dpois(na.omit(c(m)), exp(coef(efit)), log=TRUE)) - sum(dpois(na.omit(c(m)), 1, log=TRUE))
 
-stopifnot(abs(coef(efit)-truth)<0.01)
+stopifnot(abs(coef(efit)-truth)<0.02)
 stopifnot(abs(true.llk - logLik(efit))<0.2)
